/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                TERCER GRADO DE PRIMARIA (Excale 03)
/*
/*          **** CUESTIONARIO DE CONTEXTO PARA DOCENTES ****
/*
/*                 Ciclo escolar evaluado: 2005 - 2006
/*_____________________________________________________________________________
/*
/*
/*    PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE DOCENTES EN FORMATO SAS
/*
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale03_2006_Doc_Cuest.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. La sintxis realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas varibles
/*   - Lectura de variables del archivo en formato ASCII
/*   - Declara los valores perdidos por el usuario (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale03_2006_Doc_Cuest.txt
/*         as como el archivo Excale03_2006_Doc_Cuest.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE.
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la libreria y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se crear la base de datos (tabla de datos) Excale03_2006_Doc_Cuest.sas7bdat.
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale03_2006_Doc_Cuest.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS carge los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE ELABORACIN: 9 DE OCTUBRE DE 2007
/*
/*  ****************************************************************************/

/*****************************************************************************
/*    ACTUALIZACION AL 21 DE MAYO DEL 2008
/*
/*   - SE MODIFICARON LAS ETIQUETAS DE LOS REACTIVOS:
/*        sexo,edad y docente
/*
/*   - SE AGREGARON ETIQUETAS A VALORES DEL RACTIVO:
/*        edad
/*
/*   - SE AGREGARO VALOR (98) COMO PERDIDO EN REACTIVO:
/*        edad
/*
/*******************************************************************************/



LIBNAME  INEE  "C:\***\";
FILENAME docen "C:\***\Excale03_2006_Doc_Cuest.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbanas Pblicas"
                       2         ="Rurales Pblicas"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privadas"
                       6         ="Generales"
                       7         ="Tcnicas"
                       8         ="Telesecundarias"
                       9         ="Privadas";
     VALUE  $modF      "UP"      ="Urbanas Pblicas"
                       "RP"      ="Rurales Pblicas"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privadas"
                       "GRAL"    ="Generales"
                       "TEC"     ="Tcnicas"
                       "TV"      ="Telesecundarias"
                       "PRIV"    ="Privadas";
     VALUE $entestdomF "999999"  ="Respuesta omitida";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE EdadF
                       1         ="16 aos o menos"
                       2         ="17 a 20 aos"
                       3         ="21 a 25 aos"
                       4         ="26 a 30 aos"
                       5         ="31 a 35 aos"
                       6         ="36 a 40 aos"
                       7         ="41 a 45 aos"
                       8         ="46 a 50 aos"
                       9         ="51 a 55 aos"
                       10        ="56 a 60 aos"
                       11        ="61 aos o ms"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  p1_3F
                       1         ="El espaol"
                       2         ="Una lengua indgena (nhuatl, maya, purpecha, mixteco, otomi u otra)"
                       3         ="Un idioma extranjero (francs, ingls, alemn u otro)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp004F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp005F
                       1         ="Vivo solo"
                       2         ="2"
                       3         ="3"
                       4         ="4"
                       5         ="5"
                       6         ="6"
                       7         ="7 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp006F
                       1         ="1"
                       2         ="2"
                       3         ="3"
                       4         ="4"
                       5         ="5 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp007F
                       1         ="Tierra"
                       2         ="Cemento"
                       3         ="Piso de mosaico, alfombra o duela"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  p8_10F
                       0         ="Ninguno"
                       1         ="1"
                       2         ="2 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  p11_14F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp015F
                       1         ="Primaria"
                       2         ="Secundaria"
                       3         ="Preparatoria, Bachillerato o Tcnico"
                       4         ="Licenciatura"
                       5         ="Maestra"
                       6         ="Doctorado"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  p16_19F
                       1         ="Si"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp020F
                       6         ="Con clave o base(escuela pblica)"
                       5         ="Interino ilimitado(escuela pblica)"
                       4         ="Interino limitado(Escuela pblica)"
                       3         ="Contrato por honorarios(escuela privada)"
                       2         ="Contrato por nmina(escuela privada)"
                       1         ="Compensacin o beca(curso comunitario)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp021F
                       1         ="1 ao o menos"
                       2         ="De 2 a 3 aos"
                       3         ="De 4 a 5 aos"
                       4         ="De 6 a 10 aos"
                       5         ="De 11 a 20 aos"
                       6         ="De 21 a 30 aos"
                       7         ="31 aos o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp022F
                       1         ="1 ao o menos"
                       2         ="De 2 a 3 aos"
                       3         ="De 4 a 5 aos"
                       4         ="De 6 a 10 aos"
                       5         ="De 11 a 20 aos"
                       6         ="De 21 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp023F
                       1         ="Es la primera vez"
                       2         ="2 ciclos escolares"
                       3         ="3 ciclos escolares"
                       4         ="4 ciclos escolares"
                       5         ="5 ciclos escolares"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp024F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp025F
                       1         ="Espaol"
                       2         ="Matemticas"
                       3         ="Ciencias Sociales"
                       4         ="Ciencias Naturales"
                       5         ="Tengo el mismo conocimiento en todas"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp026F
                       01        ="S"
                       00        ="No"
                       96        ="No procede(trabajo en escuela privada o en curso comunitario)"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  pp027F
                       96        ="No procede(trabajo en escuela privada/curso comunitario)"
                       00        ="No incorporado"
                       01        ="Menos de 1 ao"
                       02        ="De 1 a 3 aos"
                       03        ="De 4 a 6 aos"
                       04        ="De 7 a 9 aos"
                       05        ="10 o ms aos"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  pp028F
                       96        ="No procede(trabajo en escuela privada/curso comunitario)"
                       00        ="No incorporado"
                       01        ="A"
                       02        ="B"
                       03        ="BC"
                       04        ="C"
                       05        ="D"
                       06        ="E"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  p29_30F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp031F
                       0         ="No tengo trabajo"
                       1         ="1 a 5 horas"
                       2         ="6 a 10 horas"
                       3         ="11 a 20 horas"
                       4         ="21 horas o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  p32_36F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  p37_39F
                       0         ="Ninguno"
                       1         ="1  2"
                       2         ="3  4"
                       3         ="5  ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  p40_42F
                       0         ="0%"
                       1         ="5%"
                       2         ="10%"
                       3         ="15%"
                       4         ="20%"
                       5         ="25% o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp043F
                       01        ="10 alumnos o menos"
                       02        ="11 a 15"
                       03        ="16 a 20"
                       04        ="21 a 25"
                       05        ="26 a 30"
                       06        ="31 a 35"
                       07        ="36 a 40"
                       08        ="41 o ms"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  pp044F
                       0         ="Ninguno"
                       1         ="1  2"
                       2         ="3  4"
                       3         ="5 o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp045F
                       1         ="2 horas o menos"
                       2         ="3 a 4 horas"
                       3         ="5 a 7 horas"
                       4         ="8 a 10 horas"
                       5         ="11 horas a ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  p46_49F
                       0         ="Nunca"
                       1         ="Rara vez"
                       2         ="Frecuentemente"
                       3         ="Casi siempre"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp050F
                       1         ="75%"
                       2         ="80%"
                       3         ="85%"
                       4         ="90%"
                       5         ="95%"
                       6         ="100%"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp051F
                       1         ="Semanal o quincenalmente"
                       2         ="Mensualmente"
                       3         ="Bimestralmente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp052F
                       0         ="Nunca"
                       1         ="1 a 2 veces"
                       2         ="3 a 4 veces"
                       3         ="5 veces o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp053F
                       1         ="15 minutos o menos"
                       2         ="1/2 hora"
                       3         ="1 hora"
                       4         ="1 1/2 horas"
                       5         ="2 horas"
                       6         ="2 1/2 horas o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp054F
                       0         ="No me da tiempo de corregir"
                       1         ="25%"
                       2         ="50%"
                       3         ="75%"
                       4         ="100%"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  p55_62F
                       0         ="Ningn da"
                       1         ="1 da"
                       2         ="2 das"
                       3         ="3 das"
                       4         ="4 das"
                       5         ="5 das"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp063F
                       0         ="Nunca"
                       1         ="Algunas veces"
                       2         ="Frecuentemente"
                       3         ="Siempre"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp064F
                       96        ="No procede(escuela undocente)"
                       01        ="Malo"
                       02        ="Regular"
                       03        ="Bueno"
                       04        ="Excelente"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE  pp065F
                       1         ="Bajo"
                       2         ="Medio"
                       3         ="Alto"
                       4         ="Muy Alto"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp066F
                       0         ="No existen"
                       1         ="Algunas veces"
                       2         ="Frecuentemente"
                       3         ="Siempre"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp067F
                       1         ="Bajo"
                       2         ="Medio"
                       3         ="Alto"
                       4         ="Muy Alto"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp068F
                       0         ="Nada motivados"
                       1         ="Poco motivados"
                       2         ="Motivados"
                       3         ="Muy motivados"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp069F
                       1         ="Mala"
                       2         ="Regular"
                       3         ="Buena"
                       4         ="Excelente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  p70_72F
                       0         ="Nunca"
                       1         ="Alrededor de una vez al semestre"
                       2         ="Alrededor de una vez al mes"
                       3         ="Una vez a la semana o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  p73_77F
                       1         ="Malas"
                       2         ="Regulares"
                       3         ="Buenas"
                       4         ="Excelentes"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  p78_80F
                       0         ="No hay"
                       1         ="Malas"
                       2         ="Regulares"
                       3         ="Buenas"
                       4         ="Excelentes"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  p81_94F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  p95_99F
                       1         ="Muy insatisfecho"
                       2         ="Insatisfecho"
                       3         ="Satisfecho"
                       4         ="Muy satisfecho"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  pp100F
                       1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE  ep_00F
                       1         ="Programa de Estudios de Espaol, SEP, 1993"
                       2         ="Programa de Estudios de Espaol, SEP, 2000"
                       3         ="Otro programa de Estudios de Espaol.";
     VALUE  ep1_m49F
                       0         ="Nula(0%)"
                       1         ="Inicial(25%)"
                       2         ="Media(50%)"
                       3         ="Avanzada(75%)"
                       4         ="Completa(100%)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
RUN;



DATA INEE.Excale03_2006_Doc_Cuest;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $20
       id_mod             3
       mod                $4
       entest             $6
       entestdom          $6
       id_instr           $16
       sexo               3
       edad               8
       w_doc              8
       docente            5
       pp001              3
       pp002              3
       pp003              3
       pp004              3
       pp005              3
       pp006              3
       pp007              3
       pp008              3
       pp009              3
       pp010              3
       pp011              3
       pp012              3
       pp013              3
       pp014              3
       pp015              3
       pp016              3
       pp017              3
       pp018              3
       pp019              3
       pp020              3
       pp021              3
       pp022              3
       pp023              3
       pp024              3
       pp025              3
       pp026              3
       pp027              3
       pp028              3
       pp029              3
       pp030              3
       pp031              3
       pp032              3
       pp033              3
       pp034              3
       pp035              3
       pp036              3
       pp037              3
       pp038              3
       pp039              3
       pp040              3
       pp041              3
       pp042              3
       pp043              3
       pp044              3
       pp045              3
       pp046              3
       pp047              3
       pp048              3
       pp049              3
       pp050              3
       pp051              3
       pp052              3
       pp053              3
       pp054              3
       pp055              3
       pp056              3
       pp057              3
       pp058              3
       pp059              3
       pp060              3
       pp061              3
       pp062              3
       pp063              3
       pp064              3
       pp065              3
       pp066              3
       pp067              3
       pp068              3
       pp069              3
       pp070              3
       pp071              3
       pp072              3
       pp073              3
       pp074              3
       pp075              3
       pp076              3
       pp077              3
       pp078              3
       pp079              3
       pp080              3
       pp081              3
       pp082              3
       pp083              3
       pp084              3
       pp085              3
       pp086              3
       pp087              3
       pp088              3
       pp089              3
       pp090              3
       pp091              3
       pp092              3
       pp093              3
       pp094              3
       pp095              3
       pp096              3
       pp097              3
       pp098              3
       pp099              3
       pp100              3
       ep_00              3
       ep_01              3
       ep_02              3
       ep_03              3
       ep_04              3
       ep_05              3
       ep_06              3
       ep_07              3
       ep_08              3
       ep_09              3
       ep_10              3
       ep_11              3
       ep_12              3
       ep_13              3
       ep_14              3
       ep_15              3
       ep_16              3
       ep_17              3
       ep_18              3
       ep_19              3
       ep_20              3
       ep_21              3
       ep_22              3
       ep_23              3
       ep_24              3
       ep_25              3
       ep_26              3
       ep_27              3
       ep_28              3
       ep_29              3
       ep_30              3
       ep_31              3
       ep_32              3
       ep_33              3
       ep_34              3
       ep_35              3
       ep_36              3
       ep_37              3
       ep_38              3
       ep_39              3
       ep_40              3
       ep_41              3
       ep_42              3
       ep_43              3
       ep_44              3
       ep_45              3
       ep_46              3
       ep_47              3
       ep_48              3
       ep_49              3
       ep_50              3
       ep_51              3
       ep_52              3
       ep_53              3
       ep_54              3
       ep_55              3
       ep_56              3
       ep_57              3
       ep_58              3
       ep_59              3
       ep_60              3
       ep_61              3
       ep_62              3
       ep_63              3
       ep_64              3
       ep_65              3
       ep_66              3
       ep_67              3
       ep_68              3
       ep_69              3
       ep_70              3
       ep_71              3
       ep_72              3
       ep_73              3
       ep_74              3
       ep_75              3
       ep_76              3
       ep_77              3
       ep_78              3
       ep_79              3
       ep_80              3
       ep_81              3
       ep_82              3
       ep_83              3
       ep_84              3
       ep_85              3
       ep_86              3
       ep_87              3
       ep_88              3
       ep_89              3
       ep_90              3
       ep_91              3
       ep_92              3
       ep_93              3
       ep_94              3
       ep_95              3
       mp_01              3
       mp_02              3
       mp_03              3
       mp_04              3
       mp_05              3
       mp_06              3
       mp_07              3
       mp_08              3
       mp_09              3
       mp_10              3
       mp_11              3
       mp_12              3
       mp_13              3
       mp_14              3
       mp_15              3
       mp_16              3
       mp_17              3
       mp_18              3
       mp_19              3
       mp_20              3
       mp_21              3
       mp_22              3
       mp_23              3
       mp_24              3
       mp_25              3
       mp_26              3
       mp_27              3
       mp_28              3
       mp_29              3
       mp_30              3
       mp_31              3
       mp_32              3
       mp_33              3
       mp_34              3
       mp_35              3
       mp_36              3
       mp_37              3
       mp_38              3
       mp_39              3
       mp_40              3
       mp_41              3
       mp_42              3
       mp_43              3
       mp_44              3
       mp_45              3
       mp_46              3
       mp_47              3
       mp_48              3
       mp_49              3
   ;

INFILE docen MISSOVER LINESIZE = 330;
   INPUT
       nacional            1 - 1
       escuela             2 - 5
       id_ent              6 - 7
       nom_ent             8 - 27
       id_mod             28 - 28
       mod                29 - 32
       entest             33 - 38
       entestdom          39 - 44
       id_instr           45 - 56
       sexo               57 - 57
       edad               58 - 59
       w_doc              60 - 75
       docente            76 - 80
       pp001              81 - 81
       pp002              82 - 82
       pp003              83 - 83
       pp004              84 - 84
       pp005              85 - 85
       pp006              86 - 86
       pp007              87 - 87
       pp008              88 - 88
       pp009              89 - 89
       pp010              90 - 90
       pp011              91 - 91
       pp012              92 - 92
       pp013              93 - 93
       pp014              94 - 94
       pp015              95 - 95
       pp016              96 - 96
       pp017              97 - 97
       pp018              98 - 98
       pp019              99 - 99
       pp020             100 - 100
       pp021             101 - 101
       pp022             102 - 102
       pp023             103 - 103
       pp024             104 - 104
       pp025             105 - 105
       pp026             106 - 107
       pp027             108 - 109
       pp028             110 - 111
       pp029             112 - 112
       pp030             113 - 113
       pp031             114 - 114
       pp032             115 - 115
       pp033             116 - 116
       pp034             117 - 117
       pp035             118 - 118
       pp036             119 - 119
       pp037             120 - 120
       pp038             121 - 121
       pp039             122 - 122
       pp040             123 - 123
       pp041             124 - 124
       pp042             125 - 125
       pp043             126 - 127
       pp044             128 - 128
       pp045             129 - 129
       pp046             130 - 130
       pp047             131 - 131
       pp048             132 - 132
       pp049             133 - 133
       pp050             134 - 134
       pp051             135 - 135
       pp052             136 - 136
       pp053             137 - 137
       pp054             138 - 138
       pp055             139 - 139
       pp056             140 - 140
       pp057             141 - 141
       pp058             142 - 142
       pp059             143 - 143
       pp060             144 - 144
       pp061             145 - 145
       pp062             146 - 146
       pp063             147 - 147
       pp064             148 - 149
       pp065             150 - 150
       pp066             151 - 151
       pp067             152 - 152
       pp068             153 - 153
       pp069             154 - 154
       pp070             155 - 155
       pp071             156 - 156
       pp072             157 - 157
       pp073             158 - 158
       pp074             159 - 159
       pp075             160 - 160
       pp076             161 - 161
       pp077             162 - 162
       pp078             163 - 163
       pp079             164 - 164
       pp080             165 - 165
       pp081             166 - 166
       pp082             167 - 167
       pp083             168 - 168
       pp084             169 - 169
       pp085             170 - 170
       pp086             171 - 171
       pp087             172 - 172
       pp088             173 - 173
       pp089             174 - 174
       pp090             175 - 175
       pp091             176 - 176
       pp092             177 - 177
       pp093             178 - 178
       pp094             179 - 179
       pp095             180 - 180
       pp096             181 - 181
       pp097             182 - 182
       pp098             183 - 183
       pp099             184 - 184
       pp100             185 - 185
       ep_00             186 - 186
       ep_01             187 - 187
       ep_02             188 - 188
       ep_03             189 - 189
       ep_04             190 - 190
       ep_05             191 - 191
       ep_06             192 - 192
       ep_07             193 - 193
       ep_08             194 - 194
       ep_09             195 - 195
       ep_10             196 - 196
       ep_11             197 - 197
       ep_12             198 - 198
       ep_13             199 - 199
       ep_14             200 - 200
       ep_15             201 - 201
       ep_16             202 - 202
       ep_17             203 - 203
       ep_18             204 - 204
       ep_19             205 - 205
       ep_20             206 - 206
       ep_21             207 - 207
       ep_22             208 - 208
       ep_23             209 - 209
       ep_24             210 - 210
       ep_25             211 - 211
       ep_26             212 - 212
       ep_27             213 - 213
       ep_28             214 - 214
       ep_29             215 - 215
       ep_30             216 - 216
       ep_31             217 - 217
       ep_32             218 - 218
       ep_33             219 - 219
       ep_34             220 - 220
       ep_35             221 - 221
       ep_36             222 - 222
       ep_37             223 - 223
       ep_38             224 - 224
       ep_39             225 - 225
       ep_40             226 - 226
       ep_41             227 - 227
       ep_42             228 - 228
       ep_43             229 - 229
       ep_44             230 - 230
       ep_45             231 - 231
       ep_46             232 - 232
       ep_47             233 - 233
       ep_48             234 - 234
       ep_49             235 - 235
       ep_50             236 - 236
       ep_51             237 - 237
       ep_52             238 - 238
       ep_53             239 - 239
       ep_54             240 - 240
       ep_55             241 - 241
       ep_56             242 - 242
       ep_57             243 - 243
       ep_58             244 - 244
       ep_59             245 - 245
       ep_60             246 - 246
       ep_61             247 - 247
       ep_62             248 - 248
       ep_63             249 - 249
       ep_64             250 - 250
       ep_65             251 - 251
       ep_66             252 - 252
       ep_67             253 - 253
       ep_68             254 - 254
       ep_69             255 - 255
       ep_70             256 - 256
       ep_71             257 - 257
       ep_72             258 - 258
       ep_73             259 - 259
       ep_74             260 - 260
       ep_75             261 - 261
       ep_76             262 - 262
       ep_77             263 - 263
       ep_78             264 - 264
       ep_79             265 - 265
       ep_80             266 - 266
       ep_81             267 - 267
       ep_82             268 - 268
       ep_83             269 - 269
       ep_84             270 - 270
       ep_85             271 - 271
       ep_86             272 - 272
       ep_87             273 - 273
       ep_88             274 - 274
       ep_89             275 - 275
       ep_90             276 - 276
       ep_91             277 - 277
       ep_92             278 - 278
       ep_93             279 - 279
       ep_94             280 - 280
       ep_95             281 - 281
       mp_01             282 - 282
       mp_02             283 - 283
       mp_03             284 - 284
       mp_04             285 - 285
       mp_05             286 - 286
       mp_06             287 - 287
       mp_07             288 - 288
       mp_08             289 - 289
       mp_09             290 - 290
       mp_10             291 - 291
       mp_11             292 - 292
       mp_12             293 - 293
       mp_13             294 - 294
       mp_14             295 - 295
       mp_15             296 - 296
       mp_16             297 - 297
       mp_17             298 - 298
       mp_18             299 - 299
       mp_19             300 - 300
       mp_20             301 - 301
       mp_21             302 - 302
       mp_22             303 - 303
       mp_23             304 - 304
       mp_24             305 - 305
       mp_25             306 - 306
       mp_26             307 - 307
       mp_27             308 - 308
       mp_28             309 - 309
       mp_29             310 - 310
       mp_30             311 - 311
       mp_31             312 - 312
       mp_32             313 - 313
       mp_33             314 - 314
       mp_34             315 - 315
       mp_35             316 - 316
       mp_36             317 - 317
       mp_37             318 - 318
       mp_38             319 - 319
       mp_39             320 - 320
       mp_40             321 - 321
       mp_41             322 - 322
       mp_42             323 - 323
       mp_43             324 - 324
       mp_44             325 - 325
       mp_45             326 - 326
       mp_46             327 - 327
       mp_47             328 - 328
       mp_48             329 - 329
       mp_49             330 - 330
   ;

   LABEL
       nacional     ="Variable auxiliar para obtener promedios nacionales"
       escuela      ="Identificador de la escuela"
       id_ent       ="Entidad federativa (identificador numrico)"
       nom_ent      ="Entidad federativa"
       id_mod       ="Estrato escolar o Modalidad educativa (identificador numrico)"
       mod          ="Estrato escolar o Modalidad educativa"
       entest       ="Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       entestdom    ="Variable auxiliar para identificar los dominios de estudio (subpoblaciones donde se reportan resultados) a nivel de modalidad al interior de las entidades"
       id_instr     ="Identificador del cuadernillo de examen"
       sexo         ="Sexo del Docente"
       edad         ="Edad del docente en rangos"
       w_doc        ="Peso muestral o ponderador del docente"
       docente      ="Identificador del docente"
       pp001        ="Qu lengua aprendi a hablar primero?"
       pp002        ="Qu lengua habla en su casa la mayor parte del tiempo?"
       pp003        ="Qu lengua habla en su escuela la mayor parte del tiempo?"
       pp004        ="Imparte o ha impartido clases en alguna lengua indgena?"
       pp005        ="Incluyndose cuntas personas viven en su casa?"
       pp006        ="En la casa donde vive, cuntos cuartos se usan para dormir?"
       pp007        ="De qu material es la mayor parte del piso de su casa?"
       pp008        ="Cuntos de los siguientes bienes tiene en su hogar? Auto, coche o camioneta"
       pp009        ="Cuntos de los siguientes bienes tiene en su hogar? Computadora"
       pp010        ="Cuntos de los siguientes bienes tiene en su hogar? Televisin"
       pp011        ="Su hogar cuenta con... Drenaje"
       pp012        ="Su hogar cuenta con... Lnea Telefnica"
       pp013        ="Su hogar cuenta con... Internet"
       pp014        ="Su hogar cuenta con... Horno de microondas"
       pp015        ="Cul es su nivel mximo de estudios?"
       pp016        ="Cul es su formacin especfica como docente? Marque en cada una de las opciones si curs o no estos estudios. Cursos de nivelacin pedaggica"
       pp017        ="Cul es su formacin especfica como docente? Marque en cada una de las opciones si curs o no estos estudios. Bachillerato pedaggico"
       pp018        ="Cul es su formacin especfica como docente? Marque en cada una de las opciones si curs o no estos estudios. Normal bsica sin licenciatura"
       pp019        ="Cul es su formacin especfica como docente? Marque en cada una de las opciones si curs o no estos estudios. Normal superior o Licenciatura en educacin"
       pp020        ="Qu tipo de plaza o contrato de trabajo tiene actualmente en esta escuela?"
       pp021        ="Contando este ciclo escolar, cuntos aos en total ha trabajado como docente frente a grupo? (Sin importar en qu escuela)"
       pp022        ="Contando este ciclo escolar, cuntos aos a trabajado como profesor en esta escuela?"
       pp023        ="En los ltimos cinco aos, cuntos ciclos escolares ha impartido tercer grado de primaria"
       pp024        ="Desde el inicio del ciclo escolar, usted ha sido el maestro titular del grupo que est evaluando?"
       pp025        ="En qu asignatura considera que tiene mayor preparacin?"
       pp026        ="Est usted incorporado al Programa de Estmulos de Carrera Magisterial de la SEP?"
       pp027        ="Cuntos aos lleva incorporado al Programa de Estmulos de Carrera Magisterial de la SEP?"
       pp028        ="En que nivel del Programa de Carrera Magisterial de la SEP se encuentra actualmente?"
       pp029        ="Participa en algn otro programa de estmulos para el ejercicio docente (diferente a Carrera Magisterial)?"
       pp030        ="Adems de su trabajo en esta escuela, tiene otro empleo permanente por el cual reciba una remuneracin"
       pp031        ="Cuntas horas a la semana labora usted en el otro trabajo?"
       pp032        ="En el ltimo ao, ha acreditado algn curso de actualizacin en las siguientes reas? Marque en cada opcin si o no. Espaol"
       pp033        ="En el ltimo ao, ha acreditado algn curso de actualizacin en las siguientes reas? Marque en cada opcin si o no. Matemticas"
       pp034        ="En el ltimo ao, ha acreditado algn curso de actualizacin en las siguientes reas? Marque en cada opcin si o no. Ciencias Naturales"
       pp035        ="En el ltimo ao, ha acreditado algn curso de actualizacin en las siguientes reas? Marque en cada opcin si o no. Ciencias Sociales"
       pp036        ="En el ltimo ao, ha acreditado algn curso de actualizacin en las siguientes reas? Marque en cada opcin si o no. Otras reas"
       pp037        ="Cuntos de sus alumnos tienen necesidades educativas por los siguientes problemas? Problemas fsicos (motores auditivos o visuales)"
       pp038        ="Cuntos de sus alumnos tienen necesidades educativas por los siguientes problemas? Problemas importantes para aprender"
       pp039        ="Cuntos de sus alumnos tienen necesidades educativas por los siguientes problemas? Problemas severos de conducta"
       pp040        ="Aproximadamente, qu porcentaje de alumnos de su grupo presenta los siguientes problemas? Dificultades importantes para leer"
       pp041        ="Aproximadamente, qu porcentaje de alumnos de su grupo presenta los siguientes problemas? Dificultades importantes para escribir"
       pp042        ="Aproximadamente, qu porcentaje de alumnos de su grupo presenta los siguientes problemas? Dificultades importantes para hacer clculos matemticos"
       pp043        ="Cuntos alumnos tiene en su grupo?"
       pp044        ="Por lo general, cuntos alumnos faltan a clases?"
       pp045        ="Cuntas horas a la semana invierte en preparar sus clases?"
       pp046        ="Con qu frecuencia utiliza los siguientes recursos educativos para preparar sus clases? Libros para el maestro SEP"
       pp047        ="Con qu frecuencia utiliza los siguientes recursos educativos para preparar sus clases? Ficheros SEP"
       pp048        ="Con qu frecuencia utiliza los siguientes recursos educativos para preparar sus clases? Materiales distintos a los de la SEP"
       pp049        ="Con qu frecuencia utiliza los siguientes recursos educativos para preparar sus clases? Internet"
       pp050        ="Aproximadamente, qu porcentaje del tiempo escolar le dedica a la enseanza de los contenidos curriculares?"
       pp051        ="Con qu frecuencia aplica exmenes a sus alumnos?"
       pp052        ="En este ciclo escolar, cuntas veces sus alumnos han contestado exmenes de opcin mltiple?"
       pp053        ="Aproximadamente, Cuanto tiempo al da invierten los estudiantes en hacer las tareas que les deja?"
       pp054        ="En una semana, qu porcentaje aproximado de las tareas que deja a sus alumnos le da tiempo de corregir?"
       pp055        ="Cuntos das a la semana realiza las siguientes actividades? Expone temas a los alumnos"
       pp056        ="Cuntos das a la semana realiza las siguientes actividades? Dicta a los alumnos"
       pp057        ="Cuntos das a la semana realiza las siguientes actividades? Solicita a los alumnos que realicen copias de libros o del pizarrn"
       pp058        ="Cuntos das a la semana realiza las siguientes actividades? Asigna a los alumnos ejercicios de repaso despus de ver un tema"
       pp059        ="Cuntos das a la semana realiza las siguientes actividades? Pide a los alumnos que realicen ejercicios o actividades del libro de texto"
       pp060        ="Cuntos das a la semana realiza las siguientes actividades? Pregunta a los alumnos para verificar la comprensin de contenidos"
       pp061        ="Cuntos das a la semana realiza las siguientes actividades? Asigna a los alumnos actividades para trabajar en pequeos grupos"
       pp062        ="Cuntos das a la semana realiza las siguientes actividades? Da ejemplos a los alumnos para una mejor comprensin de los temas"
       pp063        ="Con qu frecuencia les dice a sus alumnos lo que est bien y mal de su trabajo en clase?"
       pp064        ="En su opinin, cmo es el nivel de comunicacin entre los docentes de esta escuela?"
       pp065        ="En su opinin, Cmo es el nivel de exigencia acadmica de los docentes de esta escuela?"
       pp066        ="Con qu frecuencia se aplican las normas de disciplina en la escuela?"
       pp067        ="Cmo es el nivel de aprovechamiento de la mayora de los alumnos de su grupo?"
       pp068        ="Qu tan motivados para aprender estn los alumnos de su grupo?"
       pp069        ="Cmo es la disciplina de la mayora de los alumnos de su grupo?"
       pp070        ="Durante el presente ciclo escolar, Qu tan seguido se han presentado robos de objetos o dinero dentro del aula"
       pp071        ="Durante el presente ciclo escolar, qu tan seguido los alumnos de su grupo han daado las instalaciones, el mobiliario o equipo dentro del aula o la escuela?"
       pp072        ="Durante el presente ciclo escolar, qu tan seguido los alumnos de su grupo han participado en peleas a golpes dentro de la escuela?"
       pp073        ="En su opinin, cmo son las condiciones generales de la escuela en cuanto a infraestructura, equipamiento y recursos didcticos?"
       pp074        ="Cmo son las condiciones de los siguientes aspectos del lugar donde imparte clases? Iluminacin"
       pp075        ="Cmo son las condiciones de los siguientes aspectos del lugar donde imparte clases? Temperatura"
       pp076        ="Cmo son las condiciones de los siguientes aspectos del lugar donde imparte clases? Aislamiento del ruido"
       pp077        ="Cmo son las condiciones de los siguientes aspectos del lugar donde imparte clases? Ventilacin"
       pp078        ="En qu condiciones se encuentra el siguiente mobiliario? Pizarrn"
       pp079        ="En qu condiciones se encuentra el siguiente mobiliario? Escritorio del profesor"
       pp080        ="En qu condiciones se encuentra el siguiente mobiliario? Mesa-bancos o pupitres"
       pp081        ="Cuenta usted con el siguiente material para tercer grado? Plan y programas de estudio(SEP)"
       pp082        ="Cuenta usted con el siguiente material para tercer grado? Libros para el maestro (SEP)"
       pp083        ="Cuenta usted con el siguiente material para tercer grado? Libros para el alumno (SEP)"
       pp084        ="En su escuela se utiliza el siguiente material y equipo para la enseanza? Juegos didcticos"
       pp085        ="En su escuela se utiliza el siguiente material y equipo para la enseanza? Mapas y lminas"
       pp086        ="En su escuela se utiliza el siguiente material y equipo para la enseanza? Diccionarios enciclopedias y/o libros de consulta"
       pp087        ="En su escuela se utiliza el siguiente material y equipo para la enseanza? Material audiovisual"
       pp088        ="En su escuela se utiliza el siguiente material y equipo para la enseanza? Materiales Didcticos para la enseanza de matemticas (cuerpos geomtricos, juegos de geometra)"
       pp089        ="En su escuela se utiliza el siguiente material y equipo para la enseanza? Programas de cmputo"
       pp090        ="En su escuela se utiliza el siguiente material y equipo para la enseanza? Televisin"
       pp091        ="En su escuela se utiliza el siguiente material y equipo para la enseanza? Reproductor de peliculas(Beta, VHS, DVD)"
       pp092        ="En su escuela se utiliza el siguiente material y equipo para la enseanza? Computadoras"
       pp093        ="En su escuela se utiliza el siguiente material y equipo para la enseanza? Equipo audiovisual(reproductor, proyector de diapositivas)"
       pp094        ="En su escuela se utiliza el siguiente material y equipo para la enseanza? Computadoras con acceso a internet"
       pp095        ="Que tan satisfecho se encuentra con la remuneracin econmica que recibe en esta escuela"
       pp096        ="Qu tan satisfecho se encuentra de trabajar como docente en esta escuela?"
       pp097        ="Qu tan satisfecho se encuentra con sus compaeros docentes?"
       pp098        ="Qu tan satisfecho se encuentra con sus alumnos?"
       pp099        ="Qu tan satisfecho se encuentra con la funcin directiva? (Director y supervisor)"
       pp100        ="Quisiera cambiarse de escuela el prximo ciclo escolar?"
       ep_00        ="Qu Programa de Estudio de Espaol utiliz para guiar los contenidos curriculares revisados en cada clase?"
       ep_01        ="Atencin e interpretacin de mensajes de acuerdo con la situacin de comunicacin."
       ep_02        ="Identificacin y respeto de las variaciones regionales y sociales del habla."
       ep_03        ="Planeacin del contenido considerando la situacin, el propsito de la comunicacin y el tema"
       ep_04        ="Regulacin de la forma de expresin de los mensajes considerando: la claridad, la secuencia, la relacin entre las ideas, la precisin y el uso de enlaces."
       ep_05        ="Adecuacin y propiedad en el habla y en los aspectos no verbales: seleccin del lenguaje formal o informal, claridad en la pronunciacin, entonacin, volumen, gestos, movimientos corporales y contacto visual apropiado."
       ep_06        ="Reconocimiento y uso de patrones de interaccin adecuados a la situacin: participacin de turnos."
       ep_07        ="Dar y obtener informacin: identificarse a s mismo, a otros, objetos, dar recados y relatar hechos sencillos, ofreciendo explicaciones y ejemplificaciones, elaborar preguntas, plantear dudas y pedir explicaciones."
       ep_08        ="Regular/controlar las acciones propias y de otros: solicitar atencin, objetos, favores, ayudas; preguntar, convencer a otros y ofrecer ayuda"
       ep_09        ="Marcar el inicio y el final de una interaccin: saludar, presentarse, presentar a otros y despedirse."
       ep_10        ="Manifestar opiniones, expresar sentimientos y emociones propias e interesarse sobre los de otros."
       ep_11        ="Contar y disfrutar adivinanzas, chistes, trabalenguas, cuentos, poemas, rimas; escuchar y entonar canciones y rondas."
       ep_12        ="Dilogo y conversacin: usando apropiadamente el patrn de alternancia libre de turnos."
       ep_13        ="Narracin de cuentos, relatos y noticias."
       ep_14        ="Descripcin de objetos, personas, animales, procesos y lugares mediante la caracterizacin de los descrito y la precisin de atributos o funciones."
       ep_15        ="Conferencia/exposicin de temas sencillos: ideas centrales, explicaciones y ejemplos."
       ep_16        ="Discusin temtica y organizativa en grupos pequeos, asamblea y debate: definicin y concentracin en el tema, o los problemas a resolver, y las reglas de participacin."
       ep_17        ="Encuesta y entrevista: formulacin de preguntas y anlisis de respuestas."
       ep_18        ="Juegos de dramatizacin: entonacin y volumen de voz, movimientos corporales."
       ep_19        ="Direccionalidad. Partes de un texto mayor: portada ndice, captulos, hojas finales, contraportada. Partes de un texto menor o fragmento de texto: ttulos, subttulos, apartados y prrafos."
       ep_20        ="Signos de puntuacin."
       ep_21        ="Letras como marcadores de secuencias(incisos)."
       ep_22        ="Signos con significado variante o relativo: asterisco, comillas, flechas"
       ep_23        ="Letra manuscrita tipo script y cursiva"
       ep_24        ="Letra impresa y sus distintos tipos"
       ep_25        ="Artculo informativo, textos descriptivos, reportes, definiciones; en peridicos, revistas y libros de texto: tema e ideas principales."
       ep_26        ="Noticia y entrevista; en peridicos y revistas: ideas principales o puntos de vista, lugar, tiempo y participantes."
       ep_27        ="Calendario (personal o de actividades): fechas(da, mes y ao), horas y actividades."
       ep_28        ="Programaciones y programas de mano para espectculos."
       ep_29        ="Recado y aviso: destinatario, mensaje y emisor."
       ep_30        ="Anuncio comercial, cartel y folleto; descripcin y persuasin, emisor, mensaje principal, condiciones y vigencia"
       ep_31        ="Instructivo: descripcin y precisin; objetivo-meta, materiales y procedimiento."
       ep_32        ="Carta personal, formal y tarjeta de saludo: fecha, destinatario, saludo, desarrollo y final; del sobre: datos del destinatario y del remitente."
       ep_33        ="Documentos oficiales(actas, declaraciones, telegramas, formularios, credenciales y recibos)."
       ep_34        ="Cuento, relato, ancdota, fbula, leyenda e historieta: apreciacin literaria, ttulo, personajes, inicio, desarrollo, final y moraleja"
       ep_35        ="Obra de teatro: acotaciones y dilogos."
       ep_36        ="Cancin, poema o texto rimado: ritmo y rima."
       ep_37        ="Audicin de textos, lectura guiada, compartida, comentada, en episodios e independiente."
       ep_38        ="Identificacin del propsito de la lectura y del texto."
       ep_39        ="Identificar la relacin entre imagen y texto."
       ep_40        ="Estrategias de lectura: activacin de conocimientos previos, prediccin, anticipacin, muestreo e inferencias para la interpretacin del significado global y especifico."
       ep_41        ="Identificar palabras desconocidas e indagar su significado."
       ep_42        ="Comprobar la pertinencia de las predicciones, inferencias e interpretaciones, y corregir las inapropiadas."
       ep_43        ="Expresar opiniones sobre lo ledo y resumir el contenido del texto en forma oral."
       ep_44        ="Distincin realidad-fantasa"
       ep_45        ="Expresin de comentarios y opiniones en relacin con experiencias y conocimientos previos."
       ep_46        ="Exploracin libre o sugerencia de diversos materiales escritos."
       ep_47        ="Identificacin del tipo de informacin en libros, revistas, peridicos, etiquetas, anuncios y letreros."
       ep_48        ="Instalacin y uso de la biblioteca del aula."
       ep_49        ="Bsqueda o localizacin sencilla de informacin con apoyo del maestro y con propsitos propios o sugeridos. Uso del diccionario, mapas, planos, cuadros sinpticos, datos, esquemas y grficas."
       ep_50        ="Conocimiento y uso de libreras, puestos de peridicos y bibliotecas fuera del aula."
       ep_51        ="Direccionalidad. Partes de un texto mayor: ndice, captulos, hojas finales, contraportada. Partes de un texto menor o fragmento de texto: ttulos, subttulos, apartados y prrafos."
       ep_52        ="Signos de puntuacin."
       ep_53        ="Letras como marcadores de secuencias (incisos)."
       ep_54        ="Signos con significado variante o relativo: asteriscos, comillas, flechas."
       ep_55        ="Letra manuscrita tipo script y cursiva"
       ep_56        ="Letra impresa y sus distintos tipos."
       ep_57        ="Segmentacin lineal del texto: espacio entre palabras y oraciones como apoyo a la lectura."
       ep_58        ="Artculo informativo, textos descriptivos, reportes, definiciones; en peridicos, revistas y libros de texto: tema e ideas principales."
       ep_59        ="Noticia y entrevista; en peridicos y revistas: ideas principales o puntos de vista, lugar, tiempo y participantes."
       ep_60        ="Calendario (personal o de actividades): fechas(da, mes y ao), horas y actividades."
       ep_61        ="Programaciones y programas de mano para espectculos"
       ep_62        ="Recado y aviso: destinatario, mensaje y emisor."
       ep_63        ="Anuncio comercial, cartel y folleto; descripcin y persuasin, emisor, mensaje principal, condiciones y vigencia."
       ep_64        ="Instructivo: descripcin y precisin; objetivo-meta, materiales y procedimiento."
       ep_65        ="Carta personal, formal y tarjeta de saludo: fecha, destinatario, saludo, desarrollo y final; del sobre: datos del destinatario y del remitente."
       ep_66        ="Documentos oficiales(actas, declaraciones, telegramas, formularios, credenciales y recibos)."
       ep_67        ="Cuento, relato, ancdota, fbula, leyenda e historieta: apreciacin literaria, titulo, personajes, inicio, desarrollo, final y moraleja"
       ep_68        ="Obra de teatro: acotaciones y dilogos. Cancin, poema o texto rimado: ritmo y rima"
       ep_69        ="Planeacin: seleccin del tema, propsito, tipo de texto, estructura, destinatarios directos o potenciales, informacin conocida o que necesitan investigar. Organizacin de ideas en esquemas."
       ep_70        ="Redaccin, revisin y correccin de borradores: contenido. Composicin de oraciones con significado completo, claridad y funcin especifica. Composicin de prrafos descriptivos, ilustrativos y secuenciales, coherentes, con sentido unitario y completo y uso de enlaces. Inclusin de imgenes para apoyar o completar el texto. Coherencia global y uso de recursos de cohesin del texto: ttulo, subttulos, relaciones semntico-sintcticas: entre ideas e ilacin entre prrafos. Forma. Ortografa, puntuacin, legibilidad y limpieza."
       ep_71        ="Elaboracin de la versin final y publicacin o divulgacin del texto."
       ep_72        ="Anlisis de actos o situaciones comunicativas cotidianas e identificacin de sus elementos ms importantes : participantes, contextos fsicos , propsitos, mensajes y reglas de interaccin."
       ep_73        ="Identificacin de la estructura de los tipos de discurso en los que participan."
       ep_74        ="Uso adecuado de oraciones: afirmativas, negativas, interrogativas, admirativas, imperativas y desiderativas."
       ep_75        ="Transformacin de oraciones y apreciacin del cambio en el significado o sentido."
       ep_76        ="Uso de la concordancia de gnero, nmero, persona y tiempo en las oraciones."
       ep_77        ="Conocimiento de las partes de la oracin: sujeto y predicado. Sujeto explcito e implicito o tcito."
       ep_78        ="Comprensin de la nocin de clases de palabras: sustantivos propios y comunes; adjetivos, verbos, tiempos verbales, pronombres y artculos."
       ep_79        ="Uso de palabras para describir ubicacin espacial y temporal."
       ep_80        ="Conocimiento y uso de palabras conectores o enlaces."
       ep_81        ="Conocimiento y uso de sustantivos colectivos."
       ep_82        ="Reconocimiento de relaciones de significado entre palabras: palabras compuestas, campos semnticos, antnimos y sinnimos."
       ep_83        ="Reconocimiento de relaciones forma-significado de las palabras: palabras derivadas, homnimas, con prefijos para marcar oposicin o negacin(inquieto) y sufijos para marcar ocupacin(gimnasia), o aumentativos o diminutivos y singular y plural."
       ep_84        ="Interpretacin y uso de palabras y frases a partir del significado global o tema y del significado local(sintctico-semntico)."
       ep_85        ="Interpretacin de expresiones idiomticas, variantes dialectales, palabras de origen indgena y metforas. "
       ep_86        ="Uso del orden alfabtico como organizador de contenidos(listas e inventarios) y de secuencias(incisos, directorios, diccionarios)."
       ep_87        ="Reconocimiento y uso de las maysculas para marcar identidad de personas, lugares e instituciones."
       ep_88        ="Reconocimiento de las irregularidades en la correspondencia sonora grfica: b-v, h, g-j, r-rr, s-c-z, ll-y, k-c-q, x, gue-gui, ge-gi, que-qui."
       ep_89        ="Deduccin de reglas ortogrficas por combinaciones de letras: mp, mb, br, bl, r-rr."
       ep_90        ="Identificacion de slabas y slaba tnica."
       ep_91        ="Segmentacin de palabras para ajustarlas al espacio o rengln."
       ep_92        ="Reconocimiento de la segmentacin lineal del texto y apreciacin de su importancia para la legibilidad: espacio entre prrafos, oraciones y palabras."
       ep_93        ="Uso de signos de admiracin y de interrogacin; del punto al final de un texto; punto y aparte o punto y seguido para separar ideas; coma en enumeracin y guin largo al inicio de la intervencin del hablante en dilogos."
       ep_94        ="Fuentes de informacin con textos escritos, orales, visuales y mixtos."
       ep_95        ="Medios: radio, televisin y cine."
       mp_01        ="Los nmeros de cuatro cifras."
       mp_02        ="Conteos."
       mp_03        ="Agrupamientos y desagrupamientos en millares, centenas, decenas y unidades."
       mp_04        ="Lectura y escritura."
       mp_05        ="El orden de la serie numrica"
       mp_06        ="Antecesor y sucesor de un nmero."
       mp_07        ="Valor posicional."
       mp_08        ="Lectura y escritura de nmeros ordinales."
       mp_09        ="Planteamiento y resolucin de problemas ms complejos de suma y resta con nmeros hasta de tres cifras, utilizando diversos procedimientos(por ejemplo, problemas de bsqueda de faltantes o problemas que requieran dos operaciones para su solucin)."
       mp_10        ="Planteamiento y resolucin de problemas diversos de multiplicacin con nmeros hasta de dos cifras, mediante distintos procedimientos."
       mp_11        ="Algoritmo convencional de la multiplicacin."
       mp_12        ="Multiplicacin de nmeros terminados en ceros."
       mp_13        ="Planteamiento y resolucin de diversos problemas de divisin, con nmeros hasta de tres cifras mediante procedimientos no convencionales(por ejemplo, soluciones con apoyo de dibujos, suma iterada, resta o multiplicacin)."
       mp_14        ="Algoritmo de la divisin con nmeros de dos cifras entre una cifra."
       mp_15        ="Nmeros fraccionarios."
       mp_16        ="Introduccin de la nocin de fraccin en casos sencillos(por ejemplo, medios, cuartos y octavos) mediante actividades de reparto y medicin de longitudes."
       mp_17        ="Comparacin de fracciones sencillas representadas con material concreto, para observar la equivalencia entre fracciones."
       mp_18        ="Representacin convencional de las fracciones."
       mp_19        ="Planteamiento y resolucin de problemas que impliquen suma de fracciones sencillas, mediante manipulacin de material."
       mp_20        ="Medicin y comparacin de reas utilizando unidades de medida arbitrarias y retculas."
       mp_21        ="Resolucin de problemas sencillos que impliquen el uso de unidades de medida convencionales: el metro, el centmetro y el centmetro cuadrado."
       mp_22        ="Comparacin y ordenamiento de longitudes y reas utilizando medidas convencionales."
       mp_23        ="Resolucin de problemas sencillos que impliquen la medicin de longitudes utilizando el medio metro y el cuarto de metro"
       mp_24        ="Resolucin de problemas sencillos que impliquen el uso de instrumentos de medicin: el metro sin graduar y la regla graduada en centmetros."
       mp_25        ="Medicin del peso y la capacidad utilizando el kilo, el medio kilo, el cuarto de kilo, el litro, el medio litro y el cuarto de litro."
       mp_26        ="El ao, los meses, las semanas y los das."
       mp_27        ="Uso del calendario para programar actividades e identificar fechas."
       mp_28        ="Lectura del reloj de manecillas: horas y minutos."
       mp_29        ="Uso de expresiones: media hora y un cuarto de hora."
       mp_30        ="Uso de instrumentos de medicin: la balanza y el reloj."
       mp_31        ="Representacin en el plano de la ubicacin de seres y objetos del entorno inmediato."
       mp_32        ="Representacin de desplazamientos sobre el plano: trayectos tomando en cuenta puntos de referencia."
       mp_33        ="Diseo, lectura e interpretacin de croquis."
       mp_34        ="Observacin y representacin de objetos desde diversas perspectivas."
       mp_35        ="Caractersticas de los cuerpos(por ejemplo, nmero de caras, forma de las caras)."
       mp_36        ="Introduccin a la construccin de cubos utilizando diversos procesamientos."
       mp_37        ="Representacin grfica de cuerpos y objetos."
       mp_38        ="Clasificacin de cuadrilteros y tringulos a partir de sus caractersticas: igualdad de sus lados, paralelismo, perpendicularidad y simetra."
       mp_39        ="Construccin y transformacin de figuras a partir de otras figuras bsicas."
       mp_40        ="Simetra"
       mp_41        ="Ejes de simetra de una figura(identificacin y trazo)."
       mp_42        ="Construccin y reproduccin de figuras mediante diversos procedimientos."
       mp_43        ="Trazo de lneas paralelas y perpendiculares mediante doblado de papel."
       mp_44        ="Uso de la regla para trazar lneas y figuras."
       mp_45        ="Planteamiento y resolucin de problemas sencillos en los que se requiera recolectar y registrar informacin peridicamente."
       mp_46        ="Invencin y redaccin de preguntas a partir de enunciados que contienen datos numricos."
       mp_47        ="Resolucin e invencin de preguntas y problemas sencillos que puedan resolverse con los datos que contiene una ilustracin."
       mp_48        ="Prediccin de hechos y sucesos en situaciones sencillas en las que no interviene el azar."
       mp_49        ="Identificacin y realizacin de juegos en los que interviene o no interviene el azar."

   ;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char20.
       id_mod             id_modF.
       mod                $modF.
       entest             $char6.
       entestdom          $entestdomF.
       id_instr           $char16.
       sexo               sexoF.
       edad               edadF.
       pp001              p1_3F.
       pp002              p1_3F.
       pp003              p1_3F.
       pp004              pp004F.
       pp005              pp005F.
       pp006              pp006F.
       pp007              pp007F.
       pp008              p8_10F.
       pp009              p8_10F.
       pp010              p8_10F.
       pp011              p11_14F.
       pp012              p11_14F.
       pp013              p11_14F.
       pp014              p11_14F.
       pp015              pp015F.
       pp016              p16_19F.
       pp017              p16_19F.
       pp018              p16_19F.
       pp019              p16_19F.
       pp020              pp020F.
       pp021              pp021F.
       pp022              pp022F.
       pp023              pp023F.
       pp024              pp024F.
       pp025              pp025F.
       pp026              pp026F.
       pp027              pp027F.
       pp028              pp028F.
       pp029              p29_30F.
       pp030              p29_30F.
       pp031              pp031F.
       pp032              p32_36F.
       pp033              p32_36F.
       pp034              p32_36F.
       pp035              p32_36F.
       pp036              p32_36F.
       pp037              p37_39F.
       pp038              p37_39F.
       pp039              p37_39F.
       pp040              p40_42F.
       pp041              p40_42F.
       pp042              p40_42F.
       pp043              pp043F.
       pp044              pp044F.
       pp045              pp045F.
       pp046              p46_49F.
       pp047              p46_49F.
       pp048              p46_49F.
       pp049              p46_49F.
       pp050              pp050F.
       pp051              pp051F.
       pp052              pp052F.
       pp053              pp053F.
       pp054              pp054F.
       pp055              p55_62F.
       pp056              p55_62F.
       pp057              p55_62F.
       pp058              p55_62F.
       pp059              p55_62F.
       pp060              p55_62F.
       pp061              p55_62F.
       pp062              p55_62F.
       pp063              pp063F.
       pp064              pp064F.
       pp065              pp065F.
       pp066              pp066F.
       pp067              pp067F.
       pp068              pp068F.
       pp069              pp069F.
       pp070              p70_72F.
       pp071              p70_72F.
       pp072              p70_72F.
       pp073              p73_77F.
       pp074              p73_77F.
       pp075              p73_77F.
       pp076              p73_77F.
       pp077              p73_77F.
       pp078              p78_80F.
       pp079              p78_80F.
       pp080              p78_80F.
       pp081              p81_94F.
       pp082              p81_94F.
       pp083              p81_94F.
       pp084              p81_94F.
       pp085              p81_94F.
       pp086              p81_94F.
       pp087              p81_94F.
       pp088              p81_94F.
       pp089              p81_94F.
       pp090              p81_94F.
       pp091              p81_94F.
       pp092              p81_94F.
       pp093              p81_94F.
       pp094              p81_94F.
       pp095              p95_99F.
       pp096              p95_99F.
       pp097              p95_99F.
       pp098              p95_99F.
       pp099              p95_99F.
       pp100              pp100F.
       ep_00              ep_00F.
       ep_01              ep1_m49F.
       ep_02              ep1_m49F.
       ep_03              ep1_m49F.
       ep_04              ep1_m49F.
       ep_05              ep1_m49F.
       ep_06              ep1_m49F.
       ep_07              ep1_m49F.
       ep_08              ep1_m49F.
       ep_09              ep1_m49F.
       ep_10              ep1_m49F.
       ep_11              ep1_m49F.
       ep_12              ep1_m49F.
       ep_13              ep1_m49F.
       ep_14              ep1_m49F.
       ep_15              ep1_m49F.
       ep_16              ep1_m49F.
       ep_17              ep1_m49F.
       ep_18              ep1_m49F.
       ep_19              ep1_m49F.
       ep_20              ep1_m49F.
       ep_21              ep1_m49F.
       ep_22              ep1_m49F.
       ep_23              ep1_m49F.
       ep_24              ep1_m49F.
       ep_25              ep1_m49F.
       ep_26              ep1_m49F.
       ep_27              ep1_m49F.
       ep_28              ep1_m49F.
       ep_29              ep1_m49F.
       ep_30              ep1_m49F.
       ep_31              ep1_m49F.
       ep_32              ep1_m49F.
       ep_33              ep1_m49F.
       ep_34              ep1_m49F.
       ep_35              ep1_m49F.
       ep_36              ep1_m49F.
       ep_37              ep1_m49F.
       ep_38              ep1_m49F.
       ep_39              ep1_m49F.
       ep_40              ep1_m49F.
       ep_41              ep1_m49F.
       ep_42              ep1_m49F.
       ep_43              ep1_m49F.
       ep_44              ep1_m49F.
       ep_45              ep1_m49F.
       ep_46              ep1_m49F.
       ep_47              ep1_m49F.
       ep_48              ep1_m49F.
       ep_49              ep1_m49F.
       ep_50              ep1_m49F.
       ep_51              ep1_m49F.
       ep_52              ep1_m49F.
       ep_53              ep1_m49F.
       ep_54              ep1_m49F.
       ep_55              ep1_m49F.
       ep_56              ep1_m49F.
       ep_57              ep1_m49F.
       ep_58              ep1_m49F.
       ep_59              ep1_m49F.
       ep_60              ep1_m49F.
       ep_61              ep1_m49F.
       ep_62              ep1_m49F.
       ep_63              ep1_m49F.
       ep_64              ep1_m49F.
       ep_65              ep1_m49F.
       ep_66              ep1_m49F.
       ep_67              ep1_m49F.
       ep_68              ep1_m49F.
       ep_69              ep1_m49F.
       ep_70              ep1_m49F.
       ep_71              ep1_m49F.
       ep_72              ep1_m49F.
       ep_73              ep1_m49F.
       ep_74              ep1_m49F.
       ep_75              ep1_m49F.
       ep_76              ep1_m49F.
       ep_77              ep1_m49F.
       ep_78              ep1_m49F.
       ep_79              ep1_m49F.
       ep_80              ep1_m49F.
       ep_81              ep1_m49F.
       ep_82              ep1_m49F.
       ep_83              ep1_m49F.
       ep_84              ep1_m49F.
       ep_85              ep1_m49F.
       ep_86              ep1_m49F.
       ep_87              ep1_m49F.
       ep_88              ep1_m49F.
       ep_89              ep1_m49F.
       ep_90              ep1_m49F.
       ep_91              ep1_m49F.
       ep_92              ep1_m49F.
       ep_93              ep1_m49F.
       ep_94              ep1_m49F.
       ep_95              ep1_m49F.
       mp_01              ep1_m49F.
       mp_02              ep1_m49F.
       mp_03              ep1_m49F.
       mp_04              ep1_m49F.
       mp_05              ep1_m49F.
       mp_06              ep1_m49F.
       mp_07              ep1_m49F.
       mp_08              ep1_m49F.
       mp_09              ep1_m49F.
       mp_10              ep1_m49F.
       mp_11              ep1_m49F.
       mp_12              ep1_m49F.
       mp_13              ep1_m49F.
       mp_14              ep1_m49F.
       mp_15              ep1_m49F.
       mp_16              ep1_m49F.
       mp_17              ep1_m49F.
       mp_18              ep1_m49F.
       mp_19              ep1_m49F.
       mp_20              ep1_m49F.
       mp_21              ep1_m49F.
       mp_22              ep1_m49F.
       mp_23              ep1_m49F.
       mp_24              ep1_m49F.
       mp_25              ep1_m49F.
       mp_26              ep1_m49F.
       mp_27              ep1_m49F.
       mp_28              ep1_m49F.
       mp_29              ep1_m49F.
       mp_30              ep1_m49F.
       mp_31              ep1_m49F.
       mp_32              ep1_m49F.
       mp_33              ep1_m49F.
       mp_34              ep1_m49F.
       mp_35              ep1_m49F.
       mp_36              ep1_m49F.
       mp_37              ep1_m49F.
       mp_38              ep1_m49F.
       mp_39              ep1_m49F.
       mp_40              ep1_m49F.
       mp_41              ep1_m49F.
       mp_42              ep1_m49F.
       mp_43              ep1_m49F.
       mp_44              ep1_m49F.
       mp_45              ep1_m49F.
       mp_46              ep1_m49F.
       mp_47              ep1_m49F.
       mp_48              ep1_m49F.
       mp_49              ep1_m49F.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Multiple.
/*   .S o S = No contestado.
/*************************************************************************/
   IF  entestdom = "999999"  THEN entestdom = "S";
   IF  edad = 99 THEN  edad = .S;
   IF  edad = 98 THEN  edad = .M;
   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos1(241) sexo  pp001 pp002 pp003 pp004 pp005 pp006 pp007 pp008 pp009
                        pp010 pp011 pp012 pp013 pp014 pp015 pp016 pp017 pp018 pp019
                        pp020 pp021 pp022 pp023 pp024 pp025 pp029 pp030 pp031 pp032
                        pp033 pp034 pp035 pp036 pp037 pp038 pp039 pp040 pp041 pp042
                        pp044 pp045 pp046 pp047 pp048 pp049 pp050 pp051 pp052 pp053
                        pp054 pp055 pp056 pp057 pp058 pp059 pp060 pp061 pp062 pp063
                        pp065 pp066 pp067 pp068 pp069 pp070 pp071 pp072 pp073 pp074
                        pp075 pp076 pp077 pp078 pp079 pp080 pp081 pp082 pp083 pp084
                        pp085 pp086 pp087 pp088 pp089 pp090 pp091 pp092 pp093 pp094
                        pp095 pp096 pp097 pp098 pp099 pp100 ep_00 ep_01 ep_02 ep_03
                        ep_04 ep_05 ep_06 ep_07 ep_08 ep_09 ep_10 ep_11 ep_12 ep_13
                        ep_14 ep_15 ep_16 ep_17 ep_18 ep_19 ep_20 ep_21 ep_22 ep_23
                        ep_24 ep_25 ep_26 ep_27 ep_28 ep_29 ep_30 ep_31 ep_32 ep_33
                        ep_34 ep_35 ep_36 ep_37 ep_38 ep_39 ep_40 ep_41 ep_42 ep_43
                        ep_44 ep_45 ep_46 ep_47 ep_48 ep_49 ep_50 ep_51 ep_52 ep_53
                        ep_54 ep_55 ep_56 ep_57 ep_58 ep_59 ep_60 ep_61 ep_62 ep_63
                        ep_64 ep_65 ep_66 ep_67 ep_68 ep_69 ep_70 ep_71 ep_72 ep_73
                        ep_74 ep_75 ep_76 ep_77 ep_78 ep_79 ep_80 ep_81 ep_82 ep_83
                        ep_84 ep_85 ep_86 ep_87 ep_88 ep_89 ep_90 ep_91 ep_92 ep_93
                        ep_94 ep_95 mp_01 mp_02 mp_03 mp_04 mp_05 mp_06 mp_07 mp_08
                        mp_09 mp_10 mp_11 mp_12 mp_13 mp_14 mp_15 mp_16 mp_17 mp_18
                        mp_19 mp_20 mp_21 mp_22 mp_23 mp_24 mp_25 mp_26 mp_27 mp_28
                        mp_29 mp_30 mp_31 mp_32 mp_33 mp_34 mp_35 mp_36 mp_37 mp_38
                        mp_39 mp_40 mp_41 mp_42 mp_43 mp_44 mp_45 mp_46 mp_47 mp_48 mp_49;
   DO  i=1 TO 241;
         IF perdidos1{i}=8 THEN  perdidos1{i}= .M;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;


   ARRAY perdidos2(5)  pp026 pp027 pp028 pp043 pp064 ;
   DO  i=1 TO 5;
         IF perdidos2{i}=98 THEN  perdidos2{i}= .M;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   drop i;
RUN;
